package com.srs.teacher.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.teacher.domain.SysTeacherExercise;

/**
 * exerciseService接口
 *
 * @author srs
 * @date 2024-06-05
 */
public interface ISysTeacherExerciseService extends IService<SysTeacherExercise> {
    /**
     * 查询exercise
     *
     * @param exerciseId exercise主键
     * @return exercise
     */
    public SysTeacherExercise selectSysTeacherExerciseByExerciseId(Long exerciseId);

    /**
     * 查询exercise列表
     *
     * @param sysTeacherExercise exercise
     * @return exercise集合
     */
    List<SysTeacherExercise> selectSysTeacherExerciseList(SysTeacherExercise sysTeacherExercise);

    /**
     * 新增exercise
     *
     * @param sysTeacherExercise exercise
     * @return 结果
     */
    int insertSysTeacherExercise(SysTeacherExercise sysTeacherExercise);

    /**
     * 修改exercise
     *
     * @param sysTeacherExercise exercise
     * @return 结果
     */
    int updateSysTeacherExercise(SysTeacherExercise sysTeacherExercise);

    /**
     * 批量删除exercise
     *
     * @param exerciseIds 需要删除的exercise主键集合
     * @return 结果
     */
    int deleteSysTeacherExerciseByExerciseIds(Long[] exerciseIds);

    /**
     * 删除exercise信息
     *
     * @param exerciseId exercise主键
     * @return 结果
     */
    int deleteSysTeacherExerciseByExerciseId(Long exerciseId);
}
